==> greenbone-security-assistant_24.5.0.orig.tar.gz: gsa-24.5.0/src/web/components/icon/__tests__/SvgIcon.test.jsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import {describe, test, expect, testing} from '@gsa/testing';
import React, {useEffect} from 'react';
import CloneIcon from 'web/components/icon/CloneIcon';
import SvgIcon, {
  useStateWithMountCheck,
  useIsMountedRef,
} from 'web/components/icon/SvgIcon';
import {render, fireEvent, act} from 'web/utils/Testing';

const entity = {name: 'entity'};

describe('SVG icon component tests', () => {
  test('should render icon', () => {
    const handleClick = testing.fn();

    const {container} = render(
      <CloneIcon
        active={true}
        title="Clone Entity"
        value={entity}
        onClick={handleClick}
      />,
    );
    expect(container).toBeVisible();
  });

  test('should render loading state', async () => {
    let res;
    const promise = new Promise((resolve, reject) => {
      res = resolve;
    });

    const handleClick = testing.fn().mockReturnValue(promise);

    const {element} = render(
      <CloneIcon
        active={true}
        title="Clone Entity"
        value={entity}
        onClick={handleClick}
      />,
    );

    expect(element).toHaveAttribute('title', 'Clone Entity');
    fireEvent.click(element);
    expect(handleClick).toHaveBeenCalledWith(entity);
    expect(element).toHaveAttribute('title', 'Loading...');

    await act(async () => {
      res();
    });

    expect(element).toHaveAttribute('title', 'Clone Entity');
  });

  test('should render with default data-testid', () => {
    const {element} = render(<SvgIcon active={true}>{() => null}</SvgIcon>);

    expect(element).toHaveAttribute('data-testid', 'svg-icon');
  });

  test('should render with custom data-testid', () => {
    const {element} = render(
      <SvgIcon active={true} data-testid="foo">
        {() => null}
      </SvgIcon>,
    );

    expect(element).toHaveAttribute('data-testid', 'foo');
  });
});

describe('useStateWithMountCheck() hook tests', () => {
  test('should not update state when component is unmounted', () => {
    const MockComponent = () => {
      const [state, setState] = useStateWithMountCheck(true);
      const handleClick = () => {
        setState(!state);
      };
      return <div onClick={handleClick}>{state.toString()}</div>;
    };

    const {element, unmount} = render(<MockComponent />);

    expect(element).toHaveTextContent('true');
    fireEvent.click(element);
    expect(element).toHaveTextContent('false');
    unmount();
    fireEvent.click(element);
    expect(element).toHaveTextContent('false');
  });
});

describe('useIsMountedRef() hook tests', () => {
  test('should return false after component is unmounted', () => {
    const callback = testing.fn();

    const MockComponent = () => {
      const isMountedRef = useIsMountedRef();
      useEffect(() => {
        // we are not referencing a DOM node, therefore we can ignore eslint
        /* eslint-disable react-hooks/exhaustive-deps */
        return () => callback(isMountedRef.current);
        /* eslint-enable */
      }, [isMountedRef]);
      return null;
    };

    const {unmount} = render(<MockComponent />);
    unmount();
    expect(callback).toHaveBeenCalledWith(false);
  });

  test('should return true if component is mounted', () => {
    const callback = testing.fn();

    const MockComponent = () => {
      const isMountedRef = useIsMountedRef();
      useEffect(() => {
        callback(isMountedRef.current);
      }, [isMountedRef]);
      return null;
    };

    render(<MockComponent />);
    expect(callback).toHaveBeenCalledWith(true);
  });
});

==> greenbone-security-assistant_24.6.1.orig.tar.gz: gsa-24.6.1/src/web/components/icon/__tests__/SvgIcon.test.jsx <==
/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import {describe, test, expect, testing} from '@gsa/testing';
import React, {useEffect} from 'react';
import CloneIcon from 'web/components/icon/CloneIcon';
import SvgIcon, {
  useStateWithMountCheck,
  useIsMountedRef,
} from 'web/components/icon/SvgIcon';
import {render, fireEvent, act} from 'web/utils/Testing';

const entity = {name: 'entity'};

describe('SVG icon component tests', () => {
  test('should render icon', () => {
    const handleClick = testing.fn();

    const {container} = render(
      <CloneIcon
        active={true}
        title="Clone Entity"
        value={entity}
        onClick={handleClick}
      />,
    );
    expect(container).toBeVisible();
  });

  test('should render loading state', async () => {
    let res;
    const promise = new Promise(resolve => {
      res = resolve;
    });

    const handleClick = testing.fn().mockReturnValue(promise);

    const {element} = render(
      <CloneIcon
        active={true}
        title="Clone Entity"
        value={entity}
        onClick={handleClick}
      />,
    );

    expect(element).toHaveAttribute('title', 'Clone Entity');
    fireEvent.click(element);
    expect(handleClick).toHaveBeenCalledWith(entity);
    expect(element).toHaveAttribute('title', 'Loading...');

    await act(async () => {
      res();
    });

    expect(element).toHaveAttribute('title', 'Clone Entity');
  });

  test('should render with default data-testid', () => {
    const {element} = render(<SvgIcon active={true}>{() => null}</SvgIcon>);

    expect(element).toHaveAttribute('data-testid', 'svg-icon');
  });

  test('should render with custom data-testid', () => {
    const {element} = render(
      <SvgIcon active={true} data-testid="foo">
        {() => null}
      </SvgIcon>,
    );

    expect(element).toHaveAttribute('data-testid', 'foo');
  });
});

describe('useStateWithMountCheck() hook tests', () => {
  test('should not update state when component is unmounted', () => {
    const MockComponent = () => {
      const [state, setState] = useStateWithMountCheck(true);
      const handleClick = () => {
        setState(!state);
      };
      return <div onClick={handleClick}>{state.toString()}</div>;
    };

    const {element, unmount} = render(<MockComponent />);

    expect(element).toHaveTextContent('true');
    fireEvent.click(element);
    expect(element).toHaveTextContent('false');
    unmount();
    fireEvent.click(element);
    expect(element).toHaveTextContent('false');
  });
});

describe('useIsMountedRef() hook tests', () => {
  test('should return false after component is unmounted', () => {
    const callback = testing.fn();

    const MockComponent = () => {
      const isMountedRef = useIsMountedRef();
      useEffect(() => {
        // we are not referencing a DOM node, therefore we can ignore eslint
        /* eslint-disable react-hooks/exhaustive-deps */
        return () => callback(isMountedRef.current);
        /* eslint-enable */
      }, [isMountedRef]);
      return null;
    };

    const {unmount} = render(<MockComponent />);
    unmount();
    expect(callback).toHaveBeenCalledWith(false);
  });

  test('should return true if component is mounted', () => {
    const callback = testing.fn();

    const MockComponent = () => {
      const isMountedRef = useIsMountedRef();
      useEffect(() => {
        callback(isMountedRef.current);
      }, [isMountedRef]);
      return null;
    };

    render(<MockComponent />);
    expect(callback).toHaveBeenCalledWith(true);
  });
});
